gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[taler-donau] branch master updated: [header] some changes


From: gnunet
Subject: [taler-donau] branch master updated: [header] some changes
Date: Tue, 17 Oct 2023 14:47:42 +0200

This is an automated email from the git hooks/post-receive script.

lukas-matyja pushed a commit to branch master
in repository donau.

The following commit(s) were added to refs/heads/master by this push:
     new aebd885  [header] some changes
aebd885 is described below

commit aebd8850fa9747cf516cd9c470d320b7e265bf5b
Author: Matyja Lukas Adam <lukas.matyja@students.bfh.ch>
AuthorDate: Tue Oct 17 14:47:40 2023 +0200

    [header] some changes
---
 src/include/taler_donau_service.h | 35 +++++++++++++++--------------------
 1 file changed, 15 insertions(+), 20 deletions(-)

diff --git a/src/include/taler_donau_service.h 
b/src/include/taler_donau_service.h
index a210bff..8febc5c 100644
--- a/src/include/taler_donau_service.h
+++ b/src/include/taler_donau_service.h
@@ -501,7 +501,7 @@ struct TALER_BlindedDonationEnvelope
 /**
  * Information needed for a donation receipt to be signed.
  */
-struct TALER_DONAU_BlindedDonationReceipt 
+struct TALER_DONAU_BlindedUniqueDonationIdentifier
 {
   
   /**
@@ -537,9 +537,9 @@ struct TALER_DONAU_BatchIssueReceiptHandle;
 
 /**
  * Structure with information about a batch 
- * operation's result.
+ * of issue receipts.
  */
-struct TALER_DONAU_BatchIssueReceiptResult
+struct TALER_DONAU_BatchIssueReceipts
 {
   /**
    * HTTP response data
@@ -587,13 +587,13 @@ struct TALER_DONAU_BatchIssueReceiptResult
  * @param dr  response details
  */
 typedef void
-(*TALER_DONAU_BatchIssueReceiptResultCallback) (
+(*TALER_DONAU_BatchIssueReceiptsCallback) (
   void *cls,
-  const struct TALER_DONAU_BatchIssueReceiptResult *dr);
+  const struct TALER_DONAU_BatchIssueReceipts*dr);
 
 
 /**
- * Submit a batch of permissions to the donau and get the
+ * Submit a batch of issue receipts to the donau and get the
  * donau's response. This API is typically used by a charity. Note that
  * while we return the response verbatim to the caller for further processing,
  * we do already verify that the response is well-formed (i.e. that signatures
@@ -610,8 +610,8 @@ typedef void
  * @param url donau base URL
  * @param keys donau keys
  * @param charity_priv details about the contract the  is for
  * @param num_bdrs length of the @a bdr array
  * @param bdr array with details about the blinded donation receipts
  * @param cb the callback to call when a reply for this request is available
  * @param cb_cls closure for the above callback
  * @param[out] ec if NULL is returned, set to the error code explaining why 
the operation failed
@@ -624,16 +624,16 @@ TALER_DONAU_charity_issue_receipt (
   const char *url,
   struct TALER_DONAU_Keys *keys,
   const struct TALER_DONAU_CharityPrivateKey *charity_priv,
-  unsigned int num_bdrs,
-  const struct TALER_DONAU_BlindedDonationReceipts bdr[static num_bdrs],
-  TALER_DONAU_BatchIssueReceiptResultCallback cb,
+  unsigned int num_bdids,
+  const struct TALER_DONAU_BlindedUniqueDonationIdentifier bdid[static 
num_bdids],
+  TALER_DONAU_BatchIssueReceiptsCallback cb,
   void *cb_cls);
 
 /**
- * Cancel a batch  permission request. This function cannot be used
+ * Cancel a batch issue receipt request. This function cannot be used
  * on a request handle if a response is already served for it.
  *
- * @param[in]  the deposit permission request handle
+ * @param[in]  the issue receipt request handle
  */
 void
 TALER_DONAU_charity_issue_receipt_cancel (
@@ -868,9 +868,9 @@ TALER_DONAU_csr_batch_issue_cancel (
 /* ********************* GET /charities/$CHARITY_ID *********************** */
 
 /**
- *  Charity issue receipt transaction.
+ *  A Charity
  */
-struct CharityIssueReceiptTransaction
+struct Charity
 {
   /**
    * Amount issued.
@@ -882,11 +882,6 @@ struct CharityIssueReceiptTransaction
    */
    unsigned int year;
 
-  /**
-   * Hash of the BDIDs to be signed
-   */
-   struct TALER_EnvelopeHash h_blinded_bdids;
-
   /**
    * Charity's eddsa signature.
    */
@@ -610,8 +610,8 @@ typedef void
  * @param keys donau keys
  * @param charity_priv details about the contract the  is for
- * @param num_bdrs length of the @a bdr array
- * @param bdr array with details about the blinded donation receipts
+ * @param num_bdids length of the @a bdid array
+ * @param bdid array with details about the blinded donation envelopes
  * @param cb the callback to call when a reply for this request is available
  * @param cb_cls closure for the above callback

-- 
To stop receiving notification emails like this one, please contact
gnunet@gnunet.org.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]